@@ -34,6 +34,7 @@ from antlr4.dfa.DFAState import DFAState
 from antlr4.error.Errors import LexerNoViableAltException, UnsupportedOperationException
 
 class SimState(object):
+    __slots__ = ('index', 'line', 'column', 'dfaState')
 
     def __init__(self):
         self.reset()
@@ -49,6 +50,10 @@ Lexer = None
 LexerATNSimulator = None
 
 class LexerATNSimulator(ATNSimulator):
+    __slots__ = (
+        'decisionToDFA', 'recog', 'startIndex', 'line', 'column', 'mode',
+        'DEFAULT_MODE', 'MAX_CHAR_VALUE', 'prevAccept'
+    )
 
     debug = False
     dfa_debug = False
@@ -58,8 +63,6 @@ class LexerATNSimulator(ATNSimulator):
 
     ERROR = None
 
-    match_calls = 0
-
     def __init__(self, recog:Lexer, atn:ATN, decisionToDFA:list, sharedContextCache:PredictionContextCache):
         super().__init__(atn, sharedContextCache)
         self.decisionToDFA = decisionToDFA
@@ -75,6 +78,9 @@ class LexerATNSimulator(ATNSimulator):
         self.column = 0
         from antlr4.Lexer import Lexer
         self.mode = Lexer.DEFAULT_MODE
+        # Cache Lexer properties to avoid further imports
+        self.DEFAULT_MODE = Lexer.DEFAULT_MODE
+        self.MAX_CHAR_VALUE = Lexer.MAX_CHAR_VALUE
         # Used during DFA/ATN exec to record the most recent accept configuration info
         self.prevAccept = SimState()
 
@@ -86,7 +92,6 @@ class LexerATNSimulator(ATNSimulator):
         self.startIndex = simulator.startIndex
 
     def match(self, input:InputStream , mode:int):
-        self.match_calls += 1
         self.mode = mode
         mark = input.mark()
         try:
@@ -105,8 +110,7 @@ class LexerATNSimulator(ATNSimulator):
         self.startIndex = -1
         self.line = 1
         self.column = 0
-        from antlr4.Lexer import Lexer
-        self.mode = Lexer.DEFAULT_MODE
+        self.mode = self.DEFAULT_MODE
 
     def matchATN(self, input:InputStream):
         startState = self.atn.modeToStartState[self.mode]
@@ -291,8 +295,7 @@ class LexerATNSimulator(ATNSimulator):
             lexerActionExecutor.execute(self.recog, input, startIndex)
 
     def getReachableTarget(self, trans:Transition, t:int):
-        from antlr4.Lexer import Lexer
-        if trans.matches(t, 0, Lexer.MAX_CHAR_VALUE):
+        if trans.matches(t, 0, self.MAX_CHAR_VALUE):
             return trans.target
         else:
             return None
@@ -420,8 +423,7 @@ class LexerATNSimulator(ATNSimulator):
 
         elif t.serializationType in [ Transition.ATOM, Transition.RANGE, Transition.SET ]:
             if treatEofAsEpsilon:
-                from antlr4.Lexer import Lexer
-                if t.matches(Token.EOF, 0, Lexer.MAX_CHAR_VALUE):
+                if t.matches(Token.EOF, 0, self.MAX_CHAR_VALUE):
                     c = LexerATNConfig(state=t.target, config=config)
 
         return c
@@ -565,4 +567,4 @@ class LexerATNSimulator(ATNSimulator):
 
 LexerATNSimulator.ERROR = DFAState(0x7FFFFFFF, ATNConfigSet())
 
-del Lexer
\ No newline at end of file
+del Lexer
